==> miniprism-2.4.3.tgz: package/src/grammars/markdown.js <==
'use strict';

/*
 * These regexes are in some places copies of, in others modifications of, and
 * in some places wholly unrelated to the Markdown regexes found in the
 * Stackedit project, which bears this license:
 *
 * StackEdit - The Markdown editor powered by PageDown.

 * Copyright 2013 Benoit Schweblin (http://www.benoitschweblin.com)
 * Licensed under an Apache License (http://www.apache.org/licenses/LICENSE-2.0)
 */

exports.gfm = {
  block  : true,
  pattern: /^`{3}.*\n(?:[\s\S]*?)\n`{3} *(?:\n|$)/gm,
  inside : {
    'gfm-limit': {
      block: true,
      pattern: /^`{3}.*(?:\n|$)/gm,
      inside : {
        'gfm-info': {
          lookbehind: true,
          pattern   : /^(`{3}).+(?:\n|$)/
        },
        'gfm-fence': /^`{3}(?:\n|$)/gm
      }
    },
    'gfm-line': {
      block  : true,
      pattern: /^.*(?:\n|$)/gm
    },
  }
};

exports.blank = [{
  block  : true,
  pattern: /\n(?![\s\S])/mg
}, {
  block  : true,
  pattern: /^\n/mg
}];

exports['setex-h1'] = {
  block  : true,
  pattern: /^.+\n=+[ \t]*(?:\n|$)/gm,
  inside : {
    'setex-header': {
      block: true,
      pattern: /^[^=].*(?:\n|$)/gm
    },
    'setex-marker': {
      block     : true,
      pattern   : /^=+[ \t]*(?:\n|$)/
    }
  }
};

exports['setex-h2'] = {
  block  : true,
  pattern: /^(?!^- ).+\n-+[ \t]*(?:\n|$)/gm,
  inside : {
    'setex-header': {
      block: true,
      pattern: /^[^-].*(?:\n|$)/gm
    },
    'setex-marker': {
      block     : true,
      pattern   : /^-+[ \t]*(?:\n|$)/
    }
  }
};

exports.code = {
  block     : true,
  pattern   : /^(?: {4,}|\t).+(?:\n|$)/gm
};

// h1 through h6
for (var i = 1; i < 7; i++) {
  exports['h' + i] = {
    classes: [`h${i}`, 'has-folding'],
    block  : true,
    pattern: new RegExp(`^#{${i}} .*(?:\n|$)`, 'gm'),
    inside : {
      'hash folding': new RegExp(`^#{${i}} `)
    }
  };
}

exports.ul = {
  classes: ['ul', 'has-folding'],
  block  : true,
  pattern: /^[ \t]*(?:[*+\-])[ \t].*(?:\n|$)/gm,
  inside : {
    'ul-marker folding': /^[ \t]*(?:[*+\-])[ \t]/
  }
};

exports.ol = {
  block  : true,
  pattern: /^[ \t]*(?:\d+)\.[ \t].*(?:\n|$)/gm,
  inside : {
    'ol-marker': /^[ \t]*(?:\d+)\.[ \t]/
  }
};

exports.blockquote = {
  block  : true,
  pattern: /^ {0,3}> *.*(?:\n|$)/gm,
  inside : {
    'blockquote-marker': /^ {0,3}> */
  }
};

exports.hr = {
  block  : true,
  pattern: /^(?:[*\-_] *){3,}(?:\n|$)/gm
};

exports['link-def'] = {
  block  : true,
  pattern: /^ {0,3}\[.*?\]:[ \t]+.+(?:\n|$)/gm,
  inside : {
    'link-def-name': {
      pattern: /^ {0,3}\[.*?\]:/,
      inside : {
        'bracket-start': /^\[/,
        'bracket-end'  : /\](?=:$)/,
        colon: /:$/
      }
    },

    'link-def-value': /.*(?:\n|$)/
  }
};

exports.p = {
  block  : true,
  pattern: /^.+(?:\n|$)/gm,
  inside : {}
};

// jshint -W101
exports.link = {
  classes: ['link', 'has-folding'],
  pattern: /\[(?:(?:\\.)|[^\[\]])*\]\([^\(\)\s]+(?:\(\S*?\))??[^\(\)\s]*?(?:\s(?:['‘][^'’]*['’]|["“][^"”]*["”]))?\)/gm,
  inside : {
    'bracket-start folding': {
      pattern   : /(^|[^\\])\[/,
      lookbehind: true
    },

    'ref': /(?:(?:\\.)|[^\[\]])+(?=\])/,

    'bracket-end folding': /\](?=\s?\()/,
    'paren-start folding': /^\(/,
    'paren-end folding': /\)$/,
    'href folding': /.*/
  }
};

// jshint +W101
exports['link-ref'] = {
  classes: ['link-ref', 'has-folding'],
  pattern: /\[(?:.*?)\] ?\[(?:.*?)\]/g,
  inside : {
    'ref-value folding': {
      pattern: /\[[^\[\]]+\]$/,
      inside : {
        'bracket-start': /\[/,
        'ref-href'     : /[^\[\]]+(?=]$)/,
        'bracket-end'  : /\]/
      }
    },

    'ref-text': {
      pattern: /^\[[^\[\]]+\]/,
      inside : {
        'bracket-start folding': /^\[/,
        'ref'          : /^[^\[\]]+/,
        'bracket-end folding'  : /\]$/
      }
    }
  }
};

exports.em = {
  classes   : ['em', 'has-folding'],
  pattern   : /(^|[^\\])(\*|_)(\S[^\2]*?)??[^\s\\]+?\2/g,
  lookbehind: true,
  inside    : {
    'em-marker folding': /(?:^(?:\*|_))|(?:(?:\*|_)$)/
  }
};

exports.strong = {
  classes: ['strong', 'has-folding'],
  pattern: /([_\*]){2}(?:(?!\1{2}).)*\1{2}/g,
  inside : {
    'strong-marker folding': /(?:^(?:\*|_){2})|(?:(?:\*|_){2}$)/
  }
};

exports['inline-code'] = {
  classes   : ['inline-code', 'has-folding'],
  pattern   : /(^|[^\\])(`+)(?:\S.*)??[^\s`]\2/g,
  lookbehind: true,
  inside    : {
    'inline-code-marker folding': /(?:^(?:`+))|(?:(?:`+)$)/
  }
};

var inlines = {
  strong       : exports.strong,
  em           : exports.em,
  link         : exports.link,
  'inline-code': exports['inline-code'],
  'link-ref'   : exports['link-ref']
};

[
  'setex-h1',
  'setex-h2',
  'h1', 'h2', 'h3', 'h4', 'h5', 'h6',
  'ul', 'ol',
  'blockquote',
  'p'
].forEach(function(token) {
  exports[token].inside.inlines = inlines;
});

['em', 'strong'].forEach(function(token) {
  exports[token].inside = exports[token].inside || {};
  exports[token].inside.inlines = {
    link      : exports.link,
    'link-ref': exports['link-ref']
  };
});

==> miniprism-2.4.4.tgz: package/src/grammars/markdown.js <==
'use strict';

/*
 * These regexes are in some places copies of, in others modifications of, and
 * in some places wholly unrelated to the Markdown regexes found in the
 * Stackedit project, which bears this license:
 *
 * StackEdit - The Markdown editor powered by PageDown.

 * Copyright 2013 Benoit Schweblin (http://www.benoitschweblin.com)
 * Licensed under an Apache License (http://www.apache.org/licenses/LICENSE-2.0)
 */

exports.gfm = {
  block  : true,
  pattern: /^`{3}.*\n(?:[\s\S]*?)\n`{3} *(?:\n|$)/gm,
  inside : {
    'gfm-limit': {
      block: true,
      pattern: /^`{3}.*(?:\n|$)/gm,
      inside : {
        'gfm-info': {
          lookbehind: true,
          pattern   : /^(`{3}).+(?:\n|$)/
        },
        'gfm-fence': /^`{3}(?:\n|$)/gm
      }
    },
    'gfm-line': {
      block  : true,
      pattern: /^.*(?:\n|$)/gm
    },
  }
};

exports.blank = [{
  block  : true,
  pattern: /\n(?![\s\S])/mg
}, {
  block  : true,
  pattern: /^\n/mg
}];

exports['setex-h1'] = {
  block  : true,
  pattern: /^.+\n=+[ \t]*(?:\n|$)/gm,
  inside : {
    'setex-header': {
      block: true,
      pattern: /^[^=].*(?:\n|$)/gm
    },
    'setex-marker': {
      block     : true,
      pattern   : /^=+[ \t]*(?:\n|$)/
    }
  }
};

exports['setex-h2'] = {
  block  : true,
  pattern: /^(?!^- ).+\n-+[ \t]*(?:\n|$)/gm,
  inside : {
    'setex-header': {
      block: true,
      pattern: /^[^-].*(?:\n|$)/gm
    },
    'setex-marker': {
      block     : true,
      pattern   : /^-+[ \t]*(?:\n|$)/
    }
  }
};

exports.code = {
  block     : true,
  pattern   : /^(?: {4,}|\t).+(?:\n|$)/gm
};

// h1 through h6
for (var i = 1; i < 7; i++) {
  exports['h' + i] = {
    classes: [`h${i}`, 'has-folding'],
    block  : true,
    pattern: new RegExp(`^#{${i}} .*(?:\n|$)`, 'gm'),
    inside : {
      'hash folding': new RegExp(`^#{${i}} `)
    }
  };
}

exports.ul = {
  classes: ['ul', 'has-folding'],
  block  : true,
  pattern: /^[ \t]*(?:[*+\-])[ \t].*(?:\n|$)/gm,
  inside : {
    'ul-marker folding': /^[ \t]*(?:[*+\-])[ \t]/
  }
};

exports.ol = {
  block  : true,
  pattern: /^[ \t]*(?:\d+)\.[ \t].*(?:\n|$)/gm,
  inside : {
    'ol-marker': /^[ \t]*(?:\d+)\.[ \t]/
  }
};

exports.blockquote = {
  block  : true,
  pattern: /^ {0,3}> *.*(?:\n|$)/gm,
  inside : {
    'blockquote-marker': /^ {0,3}> */
  }
};

exports.hr = {
  block  : true,
  pattern: /^(?:[*\-_] *){3,}(?:\n|$)/gm
};

exports['link-def'] = {
  block  : true,
  pattern: /^ {0,3}\[.*?\]:[ \t]+.+(?:\n|$)/gm,
  inside : {
    'link-def-name': {
      pattern: /^ {0,3}\[.*?\]:/,
      inside : {
        'bracket-start': /^\[/,
        'bracket-end'  : /\](?=:$)/,
        colon: /:$/
      }
    },

    'link-def-value': /.*(?:\n|$)/
  }
};

exports.p = {
  block  : true,
  pattern: /^.+(?:\n|$)/gm,
  inside : {}
};

// jshint -W101
exports.link = {
  classes: ['link', 'has-folding'],
  pattern: /\[(?:(?:\\.)|[^\[\]])+\]\([^\(\)\s]+(?:\(\S*?\))??[^\(\)\s]*?(?:\s(?:['‘][^'’]*['’]|["“][^"”]*["”]))?\)/gm,
  inside : {
    'bracket-start folding': {
      pattern   : /(^|[^\\])\[/,
      lookbehind: true
    },

    'ref': /(?:(?:\\.)|[^\[\]])+(?=\])/,

    'bracket-end folding': /\](?=\s?\()/,
    'paren-start folding': /^\(/,
    'paren-end folding': /\)$/,
    'href folding': /.*/
  }
};

// jshint +W101
exports['link-ref'] = {
  classes: ['link-ref', 'has-folding'],
  pattern: /\[(?:.*?)\] ?\[(?:.*?)\]/g,
  inside : {
    'ref-value folding': {
      pattern: /\[[^\[\]]+\]$/,
      inside : {
        'bracket-start': /\[/,
        'ref-href'     : /[^\[\]]+(?=]$)/,
        'bracket-end'  : /\]/
      }
    },

    'ref-text': {
      pattern: /^\[[^\[\]]+\]/,
      inside : {
        'bracket-start folding': /^\[/,
        'ref'          : /^[^\[\]]+/,
        'bracket-end folding'  : /\]$/
      }
    }
  }
};

exports.em = {
  classes   : ['em', 'has-folding'],
  pattern   : /(^|[^\\])(\*|_)(\S[^\2]*?)??[^\s\\]+?\2/g,
  lookbehind: true,
  inside    : {
    'em-marker folding': /(?:^(?:\*|_))|(?:(?:\*|_)$)/
  }
};

exports.strong = {
  classes: ['strong', 'has-folding'],
  pattern: /([_\*]){2}(?:(?!\1{2}).)*\1{2}/g,
  inside : {
    'strong-marker folding': /(?:^(?:\*|_){2})|(?:(?:\*|_){2}$)/
  }
};

exports['inline-code'] = {
  classes   : ['inline-code', 'has-folding'],
  pattern   : /(^|[^\\])(`+)(?:\S.*)??[^\s`]\2/g,
  lookbehind: true,
  inside    : {
    'inline-code-marker folding': /(?:^(?:`+))|(?:(?:`+)$)/
  }
};

var inlines = {
  strong       : exports.strong,
  em           : exports.em,
  link         : exports.link,
  'inline-code': exports['inline-code'],
  'link-ref'   : exports['link-ref']
};

[
  'setex-h1',
  'setex-h2',
  'h1', 'h2', 'h3', 'h4', 'h5', 'h6',
  'ul', 'ol',
  'blockquote',
  'p'
].forEach(function(token) {
  exports[token].inside.inlines = inlines;
});

['em', 'strong'].forEach(function(token) {
  exports[token].inside = exports[token].inside || {};
  exports[token].inside.inlines = {
    link      : exports.link,
    'link-ref': exports['link-ref']
  };
});
